#include <stdio.h>
#include "matrice.h"
#include "matProd.h"

int matProd(int A[N][N], int B[N][N], int C[N][N])
{
  int i,j,k;

  for (i=0; i<N; i++)
    for (j=0; j<N; j++)
      {
        C[i][j]=0;
        for (k=0; k<N; k++)
          C[i][j]+=A[i][k]*B[k][j];
      }
  return 0;
}

int matEqualQ(int A[N][N], int B[N][N])
{
  int res=1;
  for (i=0; i<N; i++)
    for (j=0; j<N; j++)
      {
	if (A[N]!=B[N])
	  res=0;
      }
  return res;
}
